Wilsons Leather Bottom Gusset Leather Crossbody - 7 Days of Deals - Handbags & Accessories - Wilsons Leather
Description: Online Only - Enjoy chic, over-the-shoulder style with this Wilsons Leather crossbody. A buttery-soft exterior blends simplicity and convenience, with two front zipper pockets and one on the back. Add to that a bottom gusset and adjustable strap, this one was designed for the lady on-the-go.
Keywords: wilsons leather, wilson's leather, wilson leather, wilsonsleather, wilsonleather, wilsonsleather.com, wilsonleather.com, wilsons leather outlets, wilson leather outlets, women's jackets, men's jackets, leather jackets, leather handbags, leather briefcases, leather coats

Bizrate

### Extra 50% Off Sitewide! Use code GIFTS at Checkout + Free Shipping Over $50 *Continental US

- Previous
- Next

Rollover to zoom
Wilsons Leather Bottom Gusset Leather Crossbody
Item E-2-474-3D Color Info
Read Reviews | Write a Review
Online Only - Enjoy chic, over-the-shoulder style with this Wilsons Leather crossbody. A buttery-soft exterior blends simplicity and convenience, with two front zipper pockets and one on the back. Add to that a bottom gusset and adjustable strap, this one was designed for the lady on-the-go.
Select a Color
Select a Color
Select a Size
Select a Size
Qty:
Was: $120.00
Now: $49.99
Forward to a Friend
Pin It
Details

- Adjustable shoulder strap (Drop: up to 24")
- Dual front zipper pockets
- Top zipper closure
- Interior zipper pocket
- Fully lined
- Back zip-across pocket
- Genuine leather
- 9"W x 6.5"H x 1.5"D
- Made in India

Shipping & Returns

# SHIPPING INFORMATION

## Shipping Methods and Costs

Depending on the item(s) you purchase on www.wilsonsleather.com and the location to which the items will be delivered, different shipping methods will be available. Each shipping method has its own restrictions and charges that will be applied to your order. Once your order leaves our warehouse, it is handled by a carrier that may provide tracking information until your order is delivered.

At checkout, you will be prompted to choose a shipping method for your item(s). (Please note, some items may offer only one shipping method.) Shipping costs are dependent on the values of the items in your order and the shipping method you select. Your total shipping charges will automatically compute during checkout prior to the completion of your order.

Generally, you will have the option of upgrading your shipping method for faster delivery (such as Second Day, or Overnight service). If you choose to upgrade your shipping method to Second Day, your order must be received and clear credit authorization by 11:00 a.m. EST or your order may not be processed until the following business day. If you choose to upgrade your shipping method to Overnight Service, your order must be received and clear credit authorization by 11:00 a.m. EST in order to receive your package the next business day. It may take up to additional 1 business day for your order to clear credit authorization.

### 48 Contiguous United States

#### Standard Ground, (5-10 business days)

Most items may be shipped to the 48 contiguous United States via Standard Ground service. You can expect your order to arrive within 5-10 full business days. Business days are Monday-Friday, excluding federal holidays within the United States. Your order must be received and clear credit authorization by 11:00 p.m. EST or your order may not be processed until the following business day. It may take up to additional 1 business day for your order to clear credit authorization. Shipping costs for orders placed on this site are based on the value of the total order. You will be provided with the total shipping cost for your order during Checkout. *During key Holiday times, estimated transit time for standard ground will change for faster delivery.

#### 2 Day, (2 business days)

Most items may be shipped to the 48 contiguous United States via Second Day service. You can expect your order to arrive within 2 full business days. Business days are Monday-Friday, excluding federal holidays within the United States. Your order must be received and clear credit authorization by 11:00 a.m. EST or your order may not be processed until the following business day. It may take up to additional 1 business day for your order to clear credit authorization. Shipping costs for orders placed on this site are based on the value of the total order. You will be provided with the total shipping cost for your order during Checkout. P.O. Box, APO and FPO deliveries are only eligible for the Standard Ground shipping option.

#### One Day, (1 business day)

Most items may be shipped to the 48 contiguous United States via Overnight service. You can expect your order to arrive within 1-2 full business days. Business days are Monday-Friday, excluding federal holidays within the United States. Your order must be received and clear credit authorization by 11:00 a.m. EST or your order may not be processed until the following business day. It may take up to additional 1 business day for your order to clear credit authorization. Shipping costs for orders placed on this site are based on the value of the total order. You will be provided with the total shipping cost for your order during Checkout. P.O. Box, APO and FPO deliveries are only eligible for the Standard Ground shipping option.

FROM TO | Standard Ground Shipping | 2 Day Shipping | Overnight Shipping
$0 - $25.00 | $5.95 | $14.95 | $19.95
$25.01 - $100.00 | $9.95 | $19.95 | $29.95
$100.01+ | $12.95 | $24.95 | $34.95

### Canada

#### Canadian Standard Ground, (5-10 business days, 9-12 for remote province cities)

Most items may be shipped to locations in Canada via Canadian Standard Ground service. You can expect your order to arrive within 5-10 business days, or 9-12 business days in remote province cities. Business days are Monday-Friday, excluding federal holidays in the United States and Canada. Your order must be received and clear credit authorization by 11:00 p.m. EST or your order may not be processed until the following business day. It may take up to additional 1 business day for your order to clear credit authorization. Customs duties and taxes are the responsibility of the customer. The customer takes delivery of the goods when they are provided to the carrier. Delivery terms are CIP (Carriage and Insurance Paid) or CPT (Carriage Paid To) - goods are cleared for export from the United States. Value Added Tax (VAT) rates are set by the destination country. You will be able to view the total amount of applicable duty and tax/VAT plus, an international surcharge for your order during the checkout process.

#### Express Canada, (2-5 business days)

Most items may be shipped to locations in Canada via Express Canada service. You can expect your order to arrive within 2-5 business days. Business days are Monday-Friday, excluding federal holidays in the United States and Canada. Your order must be received and clear credit authorization by 11:00 a.m. EST or your order may not be processed until the following business day. It may take up to additional 1 business day for your order to clear credit authorization. Customs duties and taxes are the responsibility of the customer. The customer takes delivery of the goods when they are provided to the carrier. Delivery terms are CIP (Carriage and Insurance Paid) or CPT (Carriage Paid To)- goods are cleared for export from the United States. Value Added Tax (VAT) rates are set by the destination country. You will be able to view the total amount of applicable duty and tax/VAT plus, an international surcharge for your order during the checkout process.

FROM TO | Canada Standard Ground | Express Canada
$0 - $25.00 | $19.95 | $29.95
$25.01 - $100.00 | $24.95 | $34.95
$100.01+ | $29.95 | $39.95

### Alaska, Hawaii, Puerto Rico, US Virgin Islands, Guam

#### Standard Ground, (10-15 business days)

Most items may be shipped to Alaska, Hawaii, Puerto Rico, US Virgin Islands, Guam via Standard Ground service. You can expect your order to arrive within 10-15 full business days. Business days are Monday-Friday, excluding federal holidays within the United States. Your order must be received and clear credit authorization by 11:00 p.m. EST or your order may not be processed until the following business day. It may take up to additional 1 business day for your order to clear credit authorization. Shipping costs for orders placed on this site are based on the value of the total order. You will be provided with the total shipping cost for your order during Checkout.

FROM TO | Standard Ground Shipping
$0 - $25.00 | $13.95
$25.01 - $100.00 | $19.95
$100.01+ | $24.95

### Military APO / FPO Addresses

#### Standard Ground, (12-16 business days)

Most items may be shipped to Military APO/FPO Addresses via Standard Ground service. You can expect your order to arrive within 12-16 full business days. Business days are Monday-Friday, excluding federal holidays within the United States. Your order must be received and clear credit authorization by 11:00 p.m. EST or your order may not be processed until the following business day. It may take up to additional 1 business day for your order to clear credit authorization. Shipping costs for orders placed on this site are based on the value of the total order. You will be provided with the total shipping cost for your order during Checkout.

FROM TO | Standard Ground Shipping
$0 - $25.00 | $5.95
$25.01 - $100.00 | $9.95
$100.01+ | $12.95

### International Shipping

At this time we only ship to the United States, US Territories (Puerto Rico, US Virgin Islands, Guam), Military APO/FPO, and Canada.

# RETURNS & EXCHANGES

### Returning a purchase to our online store:

When shipping a return, you must include the bottom portion of the original packing slip within 90 days of purchase. Be certain to save the top portion of the packing slip for your records. All returns and exchanges must be new and unused, and contain all original tags and accessories.

Shipping and handling costs, gift-wrap costs and other charges are non-refundable.

We will not accept CODs or third-party billing for returned merchandise.

In the case of shipping damages, please contact the carrier or our Customer Care department at 1-866-305-4704.

You can expect a refund in the same form of payment originally used for purchase within 30 days of our receiving your returned product. Your refund will include the cost of the item, plus any applicable sales tax.

We do not accept exchanges to our online store. Please follow the above items for the return and place your replacement order either on our website www.wilsonsleather.com or with a Customer Care agent at 1-866-305-4704 from 9:00am-9:00pm EST, 7 days a week.

Items purchased at our Wilsons Leather eBay, Amazon or Sears Marketplace online stores cannot be returned or exchanged at our Wilsons Leather online store or Wilsons Leather store locations.

### Returning or exchanging a purchase to a store location:

If you choose to return your online purchase to one of our stores, the rules above still apply. You must present the original packing slip, order confirmation email, or your online purchase receipt displayed during checkout within 90 days of purchase. Without a receipt of any kind, you will need a valid photo ID and will be issued a gift card for the most recent selling price of the item.

You may exchange your online purchase at one of our store locations. You must present the original packing slip, order confirmation email, or your online purchase receipt displayed during checkout within 90 days of purchase. Without a receipt of any kind, you will need a valid photo ID and will be issued a gift card for the most recent selling price of the item. Wilsons Leather reserves the right to limit or decline returns and exchanges.

Items purchased at a Wilsons Leather store location may not be returned to our online store.

Online purchases paid for with Paypal or PayPal Credit (Formerly Bill Me Later) must be returned to our Wilsons Leather online store and cannot be returned to a Wilsons Leather store location.

Items purchased at our Wilsons Leather eBay, Amazon or Sears Marketplace online stores cannot be returned or exchanged at our Wilsons Leather online store or Wilsons Leather store locations.

### Price Adjustments:

Wilsons Leather will honor a new lower price and give a price adjustment up to 14 days after the date of the original purchase. If purchased online, contact Customer Care at 1-866-305-4704 and be ready to provide your name and order number. The Customer Care agent will verify the lower price and the refund will be placed on the original credit card or in the original form of payment. If purchased in a Wilsons Leather store, the price adjustment must be made at a store location. The customer must present proof of purchase (original sales receipt) within 14 days of purchase. The store management team will verify the date of the sale and the purchase price. The refund will be placed on the original credit card or in the original form of payment.

## Customer Reviews

Average Rating: 0 (based on 0 reviews)
Write a Review
Be the first to review this product.
Back to Top